@@ -10,8 +10,6 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-import datetime
-
 import testtools
 
 from openstack.network.v2 import network
@@ -40,6 +38,8 @@ EXAMPLE = {
     'created_at': '2016-03-09T12:14:57.233772',
     'updated_at': '2016-07-09T12:14:57.233772',
     'is_default': False,
+    'revision_number': 23,
+    'dns_domain': 24,
 }
 
 
@@ -85,10 +85,8 @@ class TestNetwork(testtools.TestCase):
         self.assertEqual(EXAMPLE['ipv6_address_scope'],
                          sot.ipv6_address_scope_id)
         self.assertEqual(EXAMPLE['description'], sot.description)
-        dt = datetime.datetime(2016, 3, 9, 12, 14, 57, 233772).replace(
-            tzinfo=None)
-        self.assertEqual(dt, sot.created_at.replace(tzinfo=None))
-        dt = datetime.datetime(2016, 7, 9, 12, 14, 57, 233772).replace(
-            tzinfo=None)
-        self.assertEqual(dt, sot.updated_at.replace(tzinfo=None))
+        self.assertEqual(EXAMPLE['created_at'], sot.created_at)
+        self.assertEqual(EXAMPLE['updated_at'], sot.updated_at)
         self.assertFalse(sot.is_default)
+        self.assertEqual(EXAMPLE['revision_number'], sot.revision_number)
+        self.assertEqual(EXAMPLE['dns_domain'], sot.dns_domain)
